@@ -14,6 +14,12 @@ struct LOGIN
   struct LOGIN *next;
 };  
 
+
+/**
+ * authorization type
+ */
+typedef enum { BASIC, DIGEST } TYPE;
+
 void add_authorization(SERVICE S, char *username, char *password, char *realm); 
 int  display_authorization(SERVICE S); 
 int  set_authorization(SERVICE S, char *realm); 
