@@ -1,8 +1,8 @@
 /**
  * Configuration file support
  *
- * Copyright (C) 2000, 2001, 2002, 2005 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -70,6 +70,7 @@ read_cfg_file(LINES *l, char *filename)
   if((file = fopen(filename, "r")) == NULL) {
     /* this is a fatal problem, but we want  
        to enlighten the user before dying   */
+    joe_error("unable to open file: %s", filename);
     display_help();
     exit(EXIT_FAILURE);
   }
@@ -85,10 +86,18 @@ read_cfg_file(LINES *l, char *filename)
      * if the line is longer than our buffer, we're 
      * just going to chuck it rather then fsck with it.
      */
-    if( p ) *p = '\0';
-    else {  
-       while((num = fgetc(file)) != EOF && num != '\n'); 
-       line[0]='\0';
+    if(p) { 
+      *p = '\0';
+    } else {  
+      /**
+       * Small fix by Gargoyle - 19/07/2006
+       * Check to see if we are at the end of the file. If so
+       * keep the line, otherwise throw it away!
+       */
+      if((num = fgetc(file)) != EOF) {
+        while((num = fgetc(file)) != EOF && num != '\n');
+        line[0]='\0';
+      }
     }
     parse(line);
     chomp(line);
