@@ -1,8 +1,8 @@
 /**
  * HTTP/HTTPS client support
  *
- * Copyright (C) 2000-2005 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -142,7 +142,7 @@ start_routine(CLIENT *client)
       y = 0; 
     }
 
-    if(client->U[y]->hostname != NULL){
+    if(client->U[y] != NULL && client->U[y]->hostname != NULL){
       if((ret = http_request(C, client->U[y], client))==FALSE){
         increment_failures();
       }
@@ -192,6 +192,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   size_t   len;
   char     fmtime[65];
 
+
   if(my.csv){
     now = time(NULL);
 #ifdef HAVE_LOCALTIME_R
@@ -216,18 +217,19 @@ http_request(CONN *C, URL *U, CLIENT *client)
   C->auth.proxy           = client->auth.proxy;
   C->auth.type.www        = client->auth.type.www;
   C->auth.type.proxy      = client->auth.type.proxy;
-  memset( C->buffer, 0, sizeof( C->buffer ));
+  memset(C->buffer, 0, sizeof(C->buffer));
 
-  if( U->protocol == UNSUPPORTED ){ 
+  if(U->protocol == UNSUPPORTED){ 
     if(my.verbose && !my.get){
       printf(
         "%s %d %6.2f secs: %7d bytes ==> %s\n",
         "UNSPPRTD", 501, 0.00, 0, "PROTOCOL NOT SUPPORTED BY SIEGE" 
       );
     } /* end if my.verbose */
+    return FALSE;
   }
 
-  if( my.delay ){
+  if(my.delay){
     pthread_sleep_np(
      (unsigned int) (((double)pthread_rand_np(&(client->rand_r_SEED)) /
                      ((double)RAND_MAX + 1) * my.delay ) + .5) 
@@ -237,7 +239,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   C->prot = U->protocol;
 
   /* record transaction start time */
-  start = times( &t_start );  
+  start = times(&t_start);  
 
   debug( 
     "attempting connection to %s:%d\n", 
@@ -246,10 +248,13 @@ http_request(CONN *C, URL *U, CLIENT *client)
   ); 
 
   if(!C->connection.reuse || C->connection.status == 0){
+    debug("client.c:%d new_socket: %s:%d", __LINE__, U->hostname, U->port); 
     C->sock = new_socket(C, U->hostname, U->port);
   }
-  if( my.keepalive )
+
+  if(my.keepalive){
     C->connection.reuse = TRUE;
+  }
 
   if(C->sock < 0){
     debug(
@@ -259,7 +264,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
     return FALSE;
   } 
 
-  debug("client.c:%d connection made: %d", __LINE__, C->sock); 
+  debug("%s:%d connection made: %d", __FILE__, __LINE__, C->sock); 
 
   if(C->prot == HTTPS){
     if(my.proxy.required){
@@ -276,13 +281,13 @@ http_request(CONN *C, URL *U, CLIENT *client)
    * write to socket with a POST or GET
    */
   if(U->calltype == URL_POST){ 
-    if((http_post(C, U->hostname, U->port, U->pathname, U->postdata, U->postlen)) < 0){
+    if((http_post(C, U)) < 0){
       C->connection.reuse = 0;
       socket_close(C);
       return FALSE;
     }
   } else { 
-    if((http_get(C, U->hostname, U->port, U->pathname)) < 0){
+    if((http_get(C, U)) < 0){
       C->connection.reuse = 0;
       socket_close(C);
       return FALSE;
@@ -291,14 +296,25 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * read from socket and collect statistics.
    */
+/*
   head     =  http_read_headers(C, U->hostname); 
   if(!head){  C->connection.reuse = 0; socket_close(C); return FALSE; } 
-  bytes    =  http_read(C); 
-  if( !my.zero_ok && (bytes < 1) ){ 
+*/
+
+  if((head = http_read_headers(C, U->hostname))==NULL){
+    C->connection.reuse = 0; 
+    socket_close(C); 
+    debug("NULL headers: %s:%d", __FILE__, __LINE__);
+    return FALSE; 
+  }
+
+  bytes = http_read(C); 
+
+  if(!my.zero_ok && (bytes < 1)){ 
     C->connection.reuse = 0; 
     socket_close(C); 
     xfree(head); 
-    puts("zero bytes");
+    debug("zero bytes %s:%d", __FILE__, __LINE__);
     return FALSE; 
   } 
   stop     =  times(&t_stop); 
@@ -356,69 +372,71 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * close the socket and free memory.
    */
-  socket_close(C);
-  
+  if(!my.keepalive){
+    socket_close(C);
+  }
+ 
   /**
    * deal with HTTP > 300 
    */
-  switch( head->code ){
-  URL  *redirect_url; /* URL in redirection request */
-  case 301:
-  case 302:
-    redirect_url = (URL*)xmalloc(sizeof(URL));
-    if(my.follow && head->redirect[0]){
-      debug("parsing redirection URL %s", head->redirect);
-      if(protocol_length(head->redirect) == 0){
+  switch(head->code){
+    URL  *redirect_url; /* URL in redirection request */
+    case 301:
+    case 302:
+      redirect_url = (URL*)xmalloc(sizeof(URL));
+      if(my.follow && head->redirect[0]){
+        debug("parsing redirection URL %s", head->redirect);
+        if(protocol_length(head->redirect) == 0){
           memcpy(redirect_url, U, sizeof(URL));
           redirect_url->pathname = head->redirect;
-      } else {
-        redirect_url = add_redirect(head->redirect, U->port, U->urlid);
+        } else {
+          redirect_url = add_redirect(head->redirect, U->port, U->urlid);
+        }
+        if((http_request(C, redirect_url, client)) == FALSE)
+          return FALSE;
       }
-      if((http_request(C, redirect_url, client)) == FALSE)
-        return FALSE;
-    }
-    xfree(redirect_url);
-    break;
-  case 401:
-    /**
-     * WWW-Authenticate challenge from the WWW server
-     */
-    client->auth.www = (client->auth.www==0)?1:client->auth.www;
-    if(( client->auth.bids.www++ ) < my.bids - 1 ){
-      if( head->auth.type.www == DIGEST ){
-        client->auth.type.www =  DIGEST;
-        break; 
+      xfree(redirect_url);
+      break;
+    case 401:
+      /**
+       * WWW-Authenticate challenge from the WWW server
+       */
+      client->auth.www = (client->auth.www==0)?1:client->auth.www;
+      if((client->auth.bids.www++) < my.bids - 1){
+        if(head->auth.type.www == DIGEST){
+          client->auth.type.www = DIGEST;
+          break; 
+        }
+        if(head->auth.type.www == BASIC){
+          client->auth.type.www =  BASIC;
+          set_authorization(WWW, head->auth.realm.www);
+        }
+        if((http_request(C, U, client)) == FALSE){
+          fprintf(stderr, "ERROR from http_request\n");
+          return FALSE;
+        }
       }
-      if(head->auth.type.www == BASIC){
-        client->auth.type.www =  BASIC;
-        set_authorization(WWW, head->auth.realm.www);
+      break;
+    case 407:
+      /**
+       * Proxy-Authenticate challenge from the proxy server.
+       */
+      client->auth.proxy = (client->auth.proxy==0)?1:client->auth.proxy;
+      if(( client->auth.bids.proxy++ ) < my.bids - 1 ){
+        if(head->auth.type.proxy == DIGEST){
+          client->auth.type.proxy =  DIGEST;
+          break;
+        }
+        if(head->auth.type.proxy == BASIC){
+          client->auth.type.proxy = BASIC;
+          set_authorization(PROXY, head->auth.realm.proxy);
+        }
+        if((http_request(C, U, client)) == FALSE)
+          return FALSE;
       }
-      if((http_request(C, U, client)) == FALSE){
-        fprintf(stderr, "ERROR from http_request\n");
-        return FALSE;
-      }
-    }
-    break;
-  case 407:
-    /**
-     * Proxy-Authenticate challenge from the proxy server.
-     */
-    client->auth.proxy = (client->auth.proxy==0)?1:client->auth.proxy;
-    if(( client->auth.bids.proxy++ ) < my.bids - 1 ){
-      if( head->auth.type.proxy == DIGEST ){
-        client->auth.type.proxy =  DIGEST;
-        break;
-      }
-      if( head->auth.type.proxy == BASIC  ){
-        client->auth.type.proxy =  BASIC;
-        set_authorization(PROXY, head->auth.realm.proxy);
-      }
-      if((http_request(C, U, client)) == FALSE)
-        return FALSE;
-    }
-    break;
-  default:
-    break;
+      break;
+    default:
+      break;
   }
 
   client->hits  ++; 
