@@ -36,6 +36,8 @@
 # include <openssl/err.h> 
 #endif /* HAVE_SSL */
 
+#include <auth.h>
+
 
 struct trans
 {
@@ -44,6 +46,36 @@ struct trans
   float time;
 };
 
+/**
+ * client data
+ */
+typedef struct
+{
+  int      id;
+  unsigned long  hits;
+  unsigned long  bytes;
+  unsigned int   code;
+  unsigned int   fail;
+  URL    **U;
+  struct {
+    int  www;
+    int  proxy;
+    struct {
+      int  www;
+      int  proxy;
+    } bids;
+    struct {
+      TYPE www;
+      TYPE proxy;
+    } type;
+  } auth;
+  int      status;
+  float    time;
+  unsigned int rand_r_SEED;
+  float bigtime;
+  float smalltime;
+} CLIENT;
+
 void * start_routine(CLIENT *client);
 
 #endif/*CLIENT_H */
