@@ -1,8 +1,8 @@
 /**
  * Signal Handling
  *
- * Copyright (C) 2000, 2001, 2002 by
- * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -41,6 +41,10 @@ spin_doctor(CREW crew)
   long x;
   char h[4] = {'-','\\','|','/'};
 
+  if(my.spinner==FALSE){
+    return;
+  }
+
   for(x = 0; crew_get_total(crew) > 1 || x < 55; x++){
     fflush(stderr);
     fprintf(stderr,"%c", h[x%4]);
