@@ -1,8 +1,8 @@
 /**
  * HTTP/HTTPS protocol support 
  *
- * Copyright (C) 2000-2005 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 #include <stdarg.h>
 #include <cookie.h>
 #include <string.h>
+#include <util.h>
 #include <joedog/defs.h>
 
 #define MAXFILE 10240
@@ -94,7 +95,7 @@ https_tunnel_response(CONN *C)
  * formats and sends an HTTP/1.0 request
  */
 int
-http_get(CONN *C, char *host, int port, char *path)
+http_get(CONN *C, URL *U)
 {
   int  rlen;
   char *protocol; 
@@ -104,7 +105,7 @@ http_get(CONN *C, char *host, int port, char *path)
   char request[REQBUF];  
   char portstr[16];
   char fullpath[4096];
-  char cookie[MAX_COOKIE_SIZE+10];
+  char cookie[MAX_COOKIE_SIZE+8];
 
   memset(cookie,  0, sizeof cookie);
   memset(request, 0, sizeof request);
@@ -113,31 +114,30 @@ http_get(CONN *C, char *host, int port, char *path)
   /* Request path based on proxy settings */
   if(my.proxy.required){
     sprintf(
-      fullpath, "%s://%s:%d%s", C->prot == HTTP?"http":"https", host, port, path 
+      fullpath, "%s://%s:%d%s", C->prot == HTTP?"http":"https", U->hostname, U->port, U->pathname 
     );
-  } 
-  else{
-    sprintf(fullpath, "%s", path);
+  } else {
+    sprintf(fullpath, "%s", U->pathname);
   }
 
-  if((port==80 && C->prot==HTTP) || (port==443 && C->prot==HTTPS)){
+  if((U->port==80 && C->prot==HTTP) || (U->port==443 && C->prot==HTTPS)){
     portstr[0] = '\0';  
   } else {
-    snprintf(portstr, sizeof portstr, ":%d", port);
+    snprintf(portstr, sizeof portstr, ":%d", U->port);
   }
 
   /* HTTP protocol string */
   protocol  = (my.protocol == TRUE)?"HTTP/1.1":"HTTP/1.0";
   keepalive = (C->connection.keepalive == TRUE)?"keep-alive":"close";
-  get_cookie_header(pthread_self(), host, cookie); 
-  if( C->auth.www ){
+  get_cookie_header(pthread_self(), U->hostname, cookie); 
+  if(C->auth.www){
     rlen = snprintf(
       authwww, sizeof(authwww), 
       "Authorization: %s %s\015\012", 
       (C->auth.type.www==BASIC)?"Basic":"Digest", my.auth.encode
     );
   }
-  if( C->auth.proxy ){
+  if(C->auth.proxy){
     rlen = snprintf(
       authpxy, sizeof(authpxy), 
       "Proxy-Authorization: %s %s\015\012", 
@@ -156,14 +156,14 @@ http_get(CONN *C, char *host, int port, char *path)
     "%s"
     "%s"
     "Accept: */*\015\012"
-    "Accept-Encoding: * \015\012"
+    "Accept-Encoding: %s\015\012"
     "User-Agent: %s\015\012%s"
     "Connection: %s\015\012\015\012",  
-    fullpath, protocol, host, portstr,
+    fullpath, protocol, U->hostname, portstr,
     (C->auth.www==TRUE)?authwww:"",
     (C->auth.proxy==TRUE)?authpxy:"",
     (strlen(cookie) > 8)?cookie:"", 
-    my.uagent, my.extra, keepalive 
+    my.encoding, my.uagent, my.extra, keepalive 
   );
   
   if(my.debug || my.get){ printf("%s\n", request); fflush(stdout); }
@@ -182,7 +182,8 @@ http_get(CONN *C, char *host, int port, char *path)
  * formats and sends an HTTP/1.0 request
  */
 int
-http_post( CONN *C, char *host, int port, char *path, char *data, size_t len )
+/*http_post(CONN *C, char *host, int port, char *path, char *data, size_t len)*/
+http_post(CONN *C, URL *U)
 {
   int  rlen;
   char authwww[128];
@@ -198,27 +199,26 @@ http_post( CONN *C, char *host, int port, char *path, char *data, size_t len )
   memset(request, 0, sizeof(request));
   memset(portstr, 0, sizeof portstr);
 
-  if( my.proxy.required ){
+  if(my.proxy.required){
    sprintf(
       fullpath, 
       "%s://%s:%d%s", 
-      C->prot == 0?"http":"https", host, port, path 
+      C->prot == 0?"http":"https", U->hostname, U->port, U->pathname
     ); 
-  }
-  else{
-    sprintf(fullpath, "%s", path);
+  } else {
+    sprintf(fullpath, "%s", U->pathname);
   }
 
-  if((port==80 && C->prot==HTTP) || (port==443 && C->prot==HTTPS)){
+  if((U->port==80 && C->prot==HTTP) || (U->port==443 && C->prot==HTTPS)){
     portstr[0] = '\0';  ;
   } else {
-    snprintf(portstr, sizeof portstr, ":%d", port);
+    snprintf(portstr, sizeof portstr, ":%d", U->port);
   }
 
   /* HTTP protocol string */
   protocol  = (my.protocol == TRUE)?"HTTP/1.1":"HTTP/1.0";
   keepalive = (C->connection.keepalive == TRUE)?"keep-alive":"close";
-  get_cookie_header(pthread_self(), host, cookie);
+  get_cookie_header(pthread_self(), U->hostname, cookie);
   if( C->auth.www ){
     rlen = snprintf(
       authwww, sizeof(authwww),
@@ -244,23 +244,23 @@ http_post( CONN *C, char *host, int port, char *path, char *data, size_t len )
     "%s"
     "%s"
     "Accept: */*\015\012"
-    "Accept-Encoding: * \015\012"
+    "Accept-Encoding: %s\015\012"
     "User-Agent: %s\015\012%s"
     "Connection: %s\015\012"
-    "Content-type: application/x-www-form-urlencoded\015\012"
+    "Content-type: %s\015\012"
     "Content-length: %ld\015\012\015\012",
-    fullpath, protocol, host, portstr,
+    fullpath, protocol, U->hostname, portstr,
     (C->auth.www==TRUE)?authwww:"",
     (C->auth.proxy==TRUE)?authpxy:"",
     (strlen(cookie) > 8)?cookie:"", 
-    my.uagent, my.extra, keepalive, (long)len
+    my.encoding, my.uagent, my.extra, keepalive, U->conttype, (long)U->postlen
   ); 
 
-  if( rlen + len < sizeof(request)){
-    memcpy(request + rlen, data, len);
-    request[rlen+len] = 0;
+  if(rlen + U->postlen < sizeof(request)){
+    memcpy(request + rlen, U->postdata, U->postlen);
+    request[rlen+U->postlen] = 0;
   }
-  rlen += len;
+  rlen += U->postlen;
   
   if(my.debug || my.get){ printf("%s\n", request); fflush(stdout); }
   if(rlen<0 || rlen>(int)sizeof(request) )
@@ -281,12 +281,11 @@ http_post( CONN *C, char *host, int port, char *path, char *data, size_t len )
 HEADERS *
 http_read_headers(CONN *C, char *host)
 { 
-  int  x;             /* while loop index      */
-  int  n;             /* assign socket_read    */
-  char c;             /* assign char read      */
-  int  len   = 0;     /* size length of line   */
-  char *line = NULL;  /* assign chars read     */
-  HEADERS *h;         /* struct to hold it all */
+  int  x;           /* while loop index      */
+  int  n;           /* assign socket_read    */
+  char c;           /* assign char read      */
+  HEADERS *h;       /* struct to hold it all */
+  char line[MAX_COOKIE_SIZE];  /* assign chars read     */
   
   h = xcalloc(sizeof(HEADERS), 1);
   
@@ -294,14 +293,12 @@ http_read_headers(CONN *C, char *host)
     x = 0;
     memset(&line, 0, sizeof(line));
     while((n = socket_read(C, &c, 1)) == 1){
-      if(x >= len){
-        len += 2048;
-        line = (char*)xrealloc(line, len);
-      }
-      line[x] = c; 
+      if(x < MAX_COOKIE_SIZE - 1)
+        line[x] = c; 
+      else 
+        line[x] = '\n';
       if(my.debug || my.get){ printf("%c", c ); fflush(stdout); }
       if((line[0] == '\n') || (line[1] == '\n')){ 
-        xfree(line);
         return h;
       }
       if(line[x] == '\n') break;
@@ -309,31 +306,25 @@ http_read_headers(CONN *C, char *host)
     }
     line[x]=0;
     /* strip trailing CR */
-    if (x > 0 && line[x-1] == '\r') line[x-1]=0;
-    if( strncasecmp( line, "http", 4 ) == 0 ){
-      strncpy( h->head, line, 8 );
-      h->code = atoi( line + 9 ); 
+    if(x > 0 && line[x-1] == '\r') line[x-1]=0;
+    if( strncasecmp(line, "http", 4) == 0){
+      strncpy( h->head, line, 8);
+      h->code = atoi(line + 9); 
     }
-    if( strncasecmp( line, "content-length: ", 16 ) == 0 ){ 
-      C->content.length = atoi( line + 16 ); 
+    if(strncasecmp(line, "content-length: ", 16) == 0){ 
+      C->content.length = atoi(line + 16); 
     }
-    if(strncasecmp( line, "set-cookie: ", 12 ) == 0){
+    if(strncasecmp(line, "set-cookie: ", 12) == 0){
       if(my.cookies){
-        char* cookie = line + 12;
-        int cookie_len = strlen(cookie);
-        if(cookie_len + 1 > (int)sizeof(h->cookie)){
-          cookie_len = (int)sizeof(h->cookie) - 1;
-        }
         memset(h->cookie, 0, sizeof(h->cookie));
-        strncpy(h->cookie, line+12, cookie_len);
+        strncpy(h->cookie, line+12, strlen(line));
         add_cookie(pthread_self(), host, h->cookie);
       }
     }
-    if(strncasecmp(line, "connection: ", 12) == 0){
+    if(strncasecmp(line, "connection: ", 12 ) == 0){
       if(strncasecmp(line+12, "keep-alive", 10) == 0){
         h->keepalive = 1;
-      }
-      else if(strncasecmp(line+12, "close", 5) == 0){
+      } else if(strncasecmp(line+12, "close", 5) == 0){
         h->keepalive = 0;
       }
     }
@@ -351,11 +342,19 @@ http_read_headers(CONN *C, char *host)
         value  = tmp;
         while(*tmp)
           tmp++;  
-        if(!strncasecmp( option, "timeout", 7)){
-          C->connection.timeout = atoi(value);
+        if(!strncasecmp(option, "timeout", 7)){
+          if(value != NULL){
+            C->connection.timeout = atoi(value);
+          } else {
+            C->connection.timeout = 15;
+          }
         }
         if(!strncasecmp(option, "max", 3)){
-          C->connection.max     = atoi(value);
+          if(value != NULL){
+            C->connection.max = atoi(value);
+          } else {
+            C->connection.max = 0;
+          }
         }
       }
     }
@@ -367,31 +366,26 @@ http_read_headers(CONN *C, char *host)
     }
     if(strncasecmp(line, "www-authenticate: ", 18) == 0){
       char *tmp;
-      int   tmp_len;
       h->auth.www = TRUE;
       if(strncasecmp(line+19, "digest", 6) == 0){
         h->auth.type.www = DIGEST;
       } else {
         h->auth.type.www = BASIC;
       }
-      tmp = strchr( line, '=' );
-      if(h->auth.www && tmp) {
-        tmp++;
-        tmp_len = strlen(tmp);
-        if(tmp[0] == '"' && tmp[tmp_len - 1] == '"'){ 
-          tmp++; 
-          tmp_len -= 2; 
-          tmp[tmp_len] = '\0'; 
-        }
-        if(tmp_len + 1 > (int)sizeof(h->auth.realm.www)){ 
-          tmp_len = (int)sizeof(h->auth.realm.www) - 1;
-        }
-        strncpy( h->auth.realm.www, tmp, tmp_len );
+      tmp = strchr(line, '=');
+      if(tmp==NULL){
+        debug("parse error: %s:%d", __FILE__, __LINE__);
+        return NULL;
       }
+      tmp++;
+      if(tmp[0] == '"'){ 
+        tmp++; 
+        tmp[strlen(tmp)-1] = '\0'; 
+      }
+      strncpy(h->auth.realm.www, tmp, strlen(tmp)); 
     }
     if(strncasecmp(line, "proxy-authenticate: ", 20) == 0){
       char *tmp;
-      int   tmp_len;
       h->auth.proxy = TRUE;
       if(strncasecmp(line+21, "digest", 6) == 0){
         h->auth.type.proxy = DIGEST;
@@ -399,41 +393,35 @@ http_read_headers(CONN *C, char *host)
         h->auth.type.proxy = BASIC;
       }   
       tmp = strchr(line, '=');
-      if(h->auth.proxy && tmp) {
-        tmp++;
-        tmp_len = strlen(tmp);
-        if(tmp[0] == '"' && tmp[tmp_len - 1] == '"'){ 
-          tmp++; 
-          tmp_len -= 2; 
-          tmp[tmp_len] = '\0'; 
-        }
-        if(tmp_len + 1 > (int)sizeof(h->auth.realm.proxy)){
-          tmp_len = (int)sizeof(h->auth.realm.proxy) - 1;
-        }
-        strncpy(h->auth.realm.proxy, tmp, tmp_len);
+      if(tmp==NULL){
+        debug("parse error: %s:%d", __FILE__, __LINE__);
+        return NULL;
       }
+      tmp++;
+      if(tmp[0] == '"'){ tmp++; tmp[strlen(tmp)-1] = '\0'; }
+      strncpy(h->auth.realm.proxy, tmp, strlen(tmp)); 
     }                      
     if(strncasecmp(line, "transfer-encoding: ", 19) == 0){
       if(strncasecmp(line+20, "chunked", 7)){
         C->content.transfer = CHUNKED; 
-      } else if(strncasecmp( line+20, "trailer", 7)){
+      } else if(strncasecmp(line+20, "trailer", 7)){
         C->content.transfer = TRAILER; 
       } else {
         C->content.transfer = NONE;
       }
     }
-    if(n == 0){
-      xfree(line);
-      return h;
+    if(strncasecmp(line, "expires: ", 9) == 0){
+      /* printf("%s\n", line+10);  */
     }
-    if(n <  0){
-      xfree(line);
-      xfree(h);
+    if(strncasecmp(line, "cache-control: ", 15) == 0){
+      /* printf("%s\n", line+15); */
+    }
+    if(n <=  0){ 
+      debug("read error: %s:%d", __FILE__, __LINE__);
       return(NULL); 
-    } 
+    } /* socket closed */
   } /* end of while TRUE */
 
-  xfree(line);
   return h;
 }
 
