@@ -31,6 +31,7 @@
 #include <sock.h>
 #include <cookie.h>
 #include <auth.h>
+#include <url.h>
 #include <joedog/joedog.h>
 #include <joedog/boolean.h>
 
@@ -66,10 +67,10 @@ struct headers
 } HEADERS;
 
 /* http function prototypes */
-int      http_get ( CONN *C, char *host, int port, char *path );
-int      http_post( CONN *C, char *host, int port, char *path, char *data, size_t len );
-HEADERS *http_read_headers( CONN *C, char * );
-ssize_t  http_read( CONN *C );
+int      http_get (CONN *C, URL *U);
+int      http_post(CONN *C, URL *U);
+HEADERS *http_read_headers(CONN *C, char *);
+ssize_t  http_read(CONN *C);
 BOOLEAN  https_tunnel_request(CONN *C, char *host, int port);
 int      https_tunnel_response(CONN *C);
 
