@@ -1,8 +1,8 @@
 /**
  * Siege environment initialization.
  *
- * Copyright (C) 2000-2004 by
- * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -118,7 +118,7 @@ init_config( void )
     (  my.password && strlen(my.password) > 0 )){
     add_authorization( WWW, my.username, my.password, "all" ); 
   }
-  if( my.proxy.hostname && strlen(my.proxy.hostname) > 0 ){
+  if(my.proxy.hostname && strlen(my.proxy.hostname) > 0){
     my.proxy.required = TRUE;
   } 
 
@@ -136,9 +136,9 @@ show_config( int EXIT )
   printf( "verbose:                        %s\n", my.verbose?"true":"false" );
   printf( "debug:                          %s\n", my.debug?"true":"false" );
   printf( "protocol:                       %s\n", my.protocol?"HTTP/1.1":"HTTP/1.0" );
-  if( my.proxy.required ){
-    printf( "proxy-host:                     %s\n", my.proxy.hostname );
-    printf( "proxy-port:                     %d\n", my.proxy.port );
+  if(my.proxy.required){
+    printf("proxy-host:                     %s\n", my.proxy.hostname);
+    printf("proxy-port:                     %d\n", my.proxy.port);
   }
   printf( "connection:                     %s\n", my.keepalive?"keep-alive":"close" );
   printf( "concurrent users:               %d\n", my.cusers );
@@ -398,7 +398,7 @@ load_conf( char *filename )
         my.protocol = FALSE; 
     }
     else if(strmatch(option, "proxy-host")){
-      my.proxy.hostname = trim(value);
+      my.proxy.hostname = xstrdup(trim(value));
     }
     else if(strmatch(option, "proxy-port")){
       if(value != NULL){
@@ -476,14 +476,13 @@ load_conf( char *filename )
         my.spinner = TRUE;
       else
         my.spinner = FALSE;
-    } 
-    else{
+    } else {
       hash_add(H, option, value);
     }
     free(tmp);
   } /* end of while line=chomp_line */
 
-  hash_destroy( H );
+  hash_destroy(H);
   fclose(fp);
   return 0;
 }
