@@ -1,8 +1,8 @@
 /**
  * Transacation logging support
  *
- * Copyright (C) 2000-2005 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@
  * simply appends to it. 
  */
 void
-log_transaction(DATA D, int failed)
+log_transaction(DATA D)
 {
   write_to_log(
     data_get_count(D),
@@ -42,7 +42,7 @@ log_transaction(DATA D, int failed)
     data_get_megabytes(D),
     data_get_total(D),
     data_get_code(D),
-    failed
+    my.failed
   );
   return;
 }
@@ -80,7 +80,7 @@ write_to_log(int count, float elapsed, int bytes, float ttime, int code, int fai
 
   if(!file_exists(my.logfile)){
     if(!create_logfile(my.logfile)){
-      joe_error("unable to create log file, do you have permission?");
+      joe_error("unable to create log file");
       return;
     }
   }
@@ -117,7 +117,7 @@ mark_log_file(char *message)
   /* if the file does NOT exist then create it.  */
   if(!file_exists(my.logfile)){
     if(!create_logfile(my.logfile)){
-      joe_error("unable to create log file, do you have permission?");
+      joe_error("unable to create log file");
       return;
     }
   }
