@@ -1,8 +1,8 @@
 /**
  * Siege, http regression tester / benchmark utility
  *
- * Copyright (C) 2000, 2001, 2002 by  
- * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * Copyright (C) 2000-2007 by  
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,6 +44,7 @@
 #include <cookie.h>
 #include <crew.h>
 #include <data.h>
+#include <version.h>
 #include <sys/resource.h>
 #ifdef __CYGWIN__
 # include <getopt.h>
@@ -83,6 +84,7 @@ static struct option long_options[] =
  * continue running? TRUE=yes, FALSE=no
  * return void
  */
+
 void 
 display_version(BOOLEAN b)
 {
@@ -91,14 +93,21 @@ display_version(BOOLEAN b)
    * adding it to a separate file allows us
    * to parse it in configure.  
    */
-  if(my.debug)
-    fprintf(stderr,"%s %s: debugging enabled\n", program_name, version_string);
-  else 
-    fprintf(stderr,"%s %s\n", program_name, version_string);
-  /**
-   * if TRUE, exit 
-   */
-  if(b == TRUE){ exit(EXIT_SUCCESS); }
+  char name[128]; 
+
+  memset(name, 0, sizeof name);
+  strncpy(name, program_name, strlen(program_name));
+
+  if(my.debug){
+    fprintf(stderr,"%s %s: debugging enabled\n\n%s\n", uppercase(name, strlen(name)), version_string, copyright);
+  } else {
+    if(b == TRUE){
+      fprintf(stderr,"%s %s\n\n%s\n", uppercase(name, strlen(name)), version_string, copyright);
+      exit(EXIT_SUCCESS);
+    } else {
+      fprintf(stderr,"%s %s\n", uppercase(name, strlen(name)), version_string);
+    }
+  }
 }  /* end of display version */
 
 /**
@@ -123,7 +132,7 @@ display_help()
   puts("  -g, --get               GET, pull down headers from the server and display HTTP");
   puts("                          transaction. Great for web application debugging.");
   puts("  -c, --concurrent=NUM    CONCURRENT users, default is 10");
-  puts("  -u, --url=\"URL\"         URL, a single user defined URL for stress testing." );
+  puts("  -u, --url=\"URL\"         Deprecated. Set URL as the last argument." );
   puts("  -i, --internet          INTERNET user simulation, hits the URLs randomly." );
   puts("  -b, --benchmark         BENCHMARK, signifies no delay for time testing." );
   puts("  -t, --time=NUMm         TIME based testing where \"m\" is the modifier S, M, or H" );
@@ -232,11 +241,13 @@ parse_cmdline(int argc, char *argv[])
         strncpy(my.file, optarg, strlen(optarg));
         break;
       case 'u':
-        my.url = (char*)strdup(optarg); 
+        printf("-u has been deprecated.\n");
+        display_help(); 
+        exit(1);
         break;
       case 'A':
-		strncpy(my.uagent, optarg, 255);
-		break;
+        strncpy(my.uagent, optarg, 255);
+        break;
       case 'R':  
         /**
          * processed above 
@@ -267,8 +278,8 @@ parse_cmdline(int argc, char *argv[])
 int 
 main(int argc, char *argv[])
 {
-  int    x; 
-  int    result;
+  int            x; 
+  int            result;
   DATA           D = new_data();
   CREW           crew;           /* thread pool - crew.h */
   LINES          *lines;         /* defined in setup.h   */
@@ -332,9 +343,6 @@ main(int argc, char *argv[])
   /* memory allocation for threads and clients */
   urls   = xmalloc(my.length * sizeof(URL));
   client = xmalloc(sizeof(CLIENT) * my.cusers);
-#if 0
-  peer   = (pthread_t*)xmalloc(sizeof(pthread_t) * my.cusers);
-#endif
   if((crew = new_crew(my.cusers, my.cusers, FALSE)) == NULL){
     joe_fatal("unable to allocate memory for %d simulated browser", my.cusers);  
   }
@@ -507,7 +515,7 @@ main(int argc, char *argv[])
   fprintf(stderr, "Shortest transaction:\t%12.2f\n",       data_get_lowest(D));
   fprintf(stderr, " \n");
   if(my.mark)    mark_log_file(my.markstr);
-  if(my.logging) log_transaction(D, my.failed);
+  if(my.logging) log_transaction(D);
 
   data_destroy(D);
   if(my.url == NULL){
@@ -517,9 +525,6 @@ main(int argc, char *argv[])
     xfree(lines);
   }  
 
-  /**
-   * exit program.
-   */
   exit(EXIT_SUCCESS);	
 } /* end of int main **/
 
