@@ -1,8 +1,8 @@
 /**
  * Package header
  *
- * Copyright (C) 2000, 2001, 2002, 2003 by
- * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -108,6 +108,8 @@ int strncmp();
 #ifndef HAVE_STRLEN
 int strlen();
 #endif
+
+#include <url.h>
 #include <joedog/joedog.h>
 #include <joedog/boolean.h>
 #include <joedog/joepath.h>
@@ -120,7 +122,17 @@ int strlen();
 #define F_DONE        4
 
 #define MAXREPS       10301062
-#define MAX_URL       4096
+
+#ifndef CHAR_BIT
+# define CHAR_BIT 8
+#endif
+
+#ifndef INT_MIN
+# define INT_MIN (~0 << (sizeof (int) * CHAR_BIT - 1))
+#endif
+#ifndef INT_MAX
+# define INT_MAX (~0 - INT_MIN)
+#endif
 
 void display_help();
 void display_version(BOOLEAN b);
@@ -160,6 +172,7 @@ struct CONFIG
   int     protocol;     /* 0=HTTP/1.0; 1=HTTP/1.1                  */
   BOOLEAN cookies;      /* to use cookies or not to use cookies    */
   char uagent[256];     /* user defined User-Agent string.         */
+  char encoding[256];   /* user defined Accept-Encoding string.    */
   char *username;       /* DEPRECATED!! */
   char *password;       /* DEPRECATED!! */ 
   int  bids;            /* W & P authorization bids before failure */
@@ -186,6 +199,7 @@ struct CONFIG
   BOOLEAN expire;       /* boolean, TRUE == expire cookies ea. run */
   BOOLEAN follow;       /* boolean, TRUE == follow 302             */
   BOOLEAN zero_ok;      /* boolean, TRUE == zero bytes data is OK. */ 
+  BOOLEAN spinner;      /* boolean, TRUE == spin, FALSE not so much*/
   char    rc[256];      /* filename of SIEGERC file                */  
   int     ssl_timeout;  /* SSL session timeout                     */
   char    *ssl_cert;    /* PEM certificate file for client auth    */
@@ -195,6 +209,7 @@ struct CONFIG
   pthread_mutex_t lock;
 };
 
+
 /**
  * struct LINES, read by read_cfg_file
  * in config.c 
@@ -205,106 +220,6 @@ typedef struct
   char **line;
 } LINES;
 
-/**
- * enum PROTOCOL
- * tcp/ip protocol
- */
-typedef enum
-{
-  HTTP        = 0,
-  HTTPS       = 1,
-  UNSUPPORTED = 2
-} PROTOCOL;
-
-/**
- * enum DIRECTIVE
- * HTTP request directive
- */
-typedef enum
-{
-  URL_GET   = 0,
-  URL_POST  = 1
-} DIRECTIVE;
-
-/**
- * authorization type
- */
-typedef enum { UNKNOWN, BASIC, DIGEST } TYPE; 
-
-/**
- * URL struct URL
- */ 
-typedef struct
-{
-  int       urlid;         /* ADDED BY jason, UNIQUE ID   */
-  PROTOCOL  protocol;      /* currently only http/https   */
-  char      *hostname;     /* DNS entry or IP address     */
-  int       port;          /* tcp port num, defs: 80, 443 */
-  char      *pathname;     /* path to http resource.      */
-  DIRECTIVE calltype;      /* request: GET/POST/HEAD etc. */
-  size_t    postlen;       /* length of POST data         */
-  char      *postdata;
-  char      *posttemp;
-  char      url[MAX_URL];
-} URL;
-
-/**
- * client data
- */
-typedef struct
-{
-  int      id;
-  unsigned long  hits;
-  unsigned long  bytes;
-  unsigned int   code;
-  unsigned int   fail;
-  URL    **U;
-  struct {
-    int  www;
-    int  proxy;
-    struct { 
-      int  www;
-      int  proxy;
-    } bids;
-    struct {
-      TYPE www;
-      TYPE proxy;
-    } type;
-  } auth;
-  int      status;
-  float    time;
-  unsigned int rand_r_SEED; 
-  float bigtime;
-  float smalltime;
-} CLIENT;  
-
-
-/**
- * cookie node
- */
-typedef struct CNODE
-{
-  int    index;
-  pthread_t threadID;
-  char   *name;
-  char   *value;
-  char   *path;
-  char   *domain;
-  time_t expires;
-  char   *expirestr;
-  char   *version;
-  char   *max;
-  int    secure;
-  struct CNODE  *next;
-} CNODE;
-
-typedef struct
-{
-  CNODE *first;
-  pthread_mutex_t mutex; 
-} COOKIE;
-
-
 #if INTERN
 # define EXTERN /* */
 #else
@@ -312,8 +227,5 @@ typedef struct
 #endif
  
 EXTERN struct CONFIG my;
-EXTERN char   *version_string; 
-EXTERN char   *program_name;
-EXTERN COOKIE *cookie; 
 
 #endif  /* SETUP_H */
