@@ -1,8 +1,8 @@
 /**
  * SIEGE socket library
  *
- * Copyright (C) 2000-2006 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -363,6 +363,7 @@ __ssl_socket_write( CONN *C, const void *vbuf, size_t len )
 {
   size_t      n;
   ssize_t     w;
+  int         err;
   const char *buf;
 
   buf = vbuf;
@@ -370,12 +371,31 @@ __ssl_socket_write( CONN *C, const void *vbuf, size_t len )
 #ifdef HAVE_SSL
   while(n > 0){
     if((w = SSL_write(C->ssl, buf, n)) <= 0){
+      if(w < 0) {
+        err = SSL_get_error(C->ssl, w);
+
+        switch(err) {
+          case SSL_ERROR_WANT_READ:
+          case SSL_ERROR_WANT_WRITE:
+          return 0;
+        case SSL_ERROR_SYSCALL:
+          joe_error("SSL_write() failed (syscall)");
+          return -1;
+        case SSL_ERROR_SSL:
+          return -1;
+       }
+    }
+    joe_error("SSL_write() failed.");
+    return -1;
+  }
+/*****************************      
       if(errno == EINTR){
         w = 0;
       } else {
+        perror("SSL_write");
         return -1;
       }
-    }
+*****************************/
     n   -= w;
     buf += w;
   }
@@ -514,10 +534,19 @@ socket_write(CONN *C, const void *buf, size_t len)
   if(C->encrypt == TRUE){
     /* handle HTTPS protocol */
     #ifdef HAVE_SSL
-    if((bytes = __ssl_socket_write(C, buf, len)) != len){
-      joe_error("ssl_socket_write: %s:%d", __FILE__, __LINE__);
-      return -1;
-    }
+    /** 
+     * Yeah, sure, this looks like a potential 
+     * endless loop, (see: Loop, endless), but 
+     * a socket timeout will break it...
+     */
+    do{
+      if((bytes = __ssl_socket_write(C, buf, len)) != len){
+        if(bytes == 0)
+          ;
+        else 
+          return -1;
+      }
+    } while(bytes == 0);
     #else
     joe_error("%s:%d protocol NOT supported", __FILE__, __LINE__);
     return -1;
