@@ -47,6 +47,8 @@
 # include <openssl/pem.h>
 #endif/*HAVE_SSL*/
 
+#include <auth.h>
+#include <url.h>
 #include <joedog/boolean.h>
 
 typedef enum
