@@ -1,8 +1,8 @@
 /**
  * URL Processing
  *
- * Copyright (C) 2000-2006 by
- * Jeffrey Fulmer - <jeff@joedog.org>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -256,6 +256,7 @@ process_post_data(URL *U, char *datap)
   } else {
     U->postdata = xstrdup(datap);
     U->postlen  = strlen(U->postdata);
+    U->conttype = xstrdup("application/x-www-form-urlencoded");
     return;
   }
   return;
