@@ -1,8 +1,8 @@
 /**
  * Utility Functions
  *
- * Copyright (C) 2000, 2001, 2002 by
- * Jeffrey Fulmer - <jdfulmer@armstrong.com>
+ * Copyright (C) 2000-2007 by
+ * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * This file is distributed as part of Siege 
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include <setup.h>
 #include <sys/types.h>
 #include <stdlib.h>
+#include <ctype.h>
 #include <joedog/boolean.h>
 #include <joedog/defs.h>
 
@@ -67,7 +68,7 @@ parse_time(char *p)
   return;
 }
 
-int
+BOOLEAN
 strmatch(char *option, char *param)
 {
   if(!strncasecmp(option,param,strlen(param))&&strlen(option)==strlen(param))
@@ -76,6 +77,35 @@ strmatch(char *option, char *param)
     return FALSE;
 }
 
+char *
+uppercase(char *s, size_t len){
+  unsigned char *c, *e;
+
+  c = (unsigned char*)s;
+  e = c+len;
+
+  while(c < e){
+    *c = TOUPPER((unsigned char)(*c));
+    c++;
+  }
+  return s;
+}
+
+
+char *
+lowercase(char *s, size_t len){
+  unsigned char *c, *e;
+
+  c = (unsigned char*)s;
+  e = c+len;
+
+  while(c < e){
+    *c = TOLOWER((unsigned char)(*c));
+    c++;
+  }
+  return s;
+}
+
 /**
  * sleep and usleep work on all supported
  * platforms except solaris, so we'll use
