@@ -1,7 +1,8 @@
 /**
  * Utility Functions
  *
- * Copyright (C) 2001 Jeffrey Fulmer <jdfulmer@armstrong.com>
+ * Copyright (C) 2001-2007 
+ * by Jeffrey Fulmer <jeff@joedog.org>, et al.
  * This file is part of Siege
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,12 +24,16 @@
 #ifndef  UTIL_H
 #define  UTIL_H
 
-void parse_time( char *p );
+#include <joedog/boolean.h>
 
-void pthread_sleep_np( unsigned int seconds ); 
-void pthread_usleep_np( unsigned long usec ); 
-int  pthread_rand_np(unsigned int *ctx); 
-int  strmatch( char *str1, char *str2 );
-void debug(const char *fmt, ...);
+void    parse_time(char *p);
+void    pthread_sleep_np(unsigned int seconds); 
+void    pthread_usleep_np(unsigned long usec); 
+int     pthread_rand_np(unsigned int *ctx); 
+BOOLEAN strmatch(char *str1, char *str2);
+void    debug(const char *fmt, ...);
+char    *uppercase(char *s, size_t len);
+char    *lowercase(char *s, size_t len);
 
 #endif /*UTIL_H*/
+
